@@ -42,8 +42,10 @@ class Company(Scraper):
     company_type = None
     company_size = None
     specialties = None
-    showcase_pages =[]
+    showcase_pages = []
     affiliated_companies = []
+    employees = []
+    headcount = None
 
     def __init__(self, linkedin_url = None, name = None, about_us =None, website = None, headquarters = None, founded = None, industry = None, company_type = None, company_size = None, specialties = None, showcase_pages =[], affiliated_companies = [], driver = None, scrape = True, get_employees = True, close_on_complete = True):
         self.linkedin_url = linkedin_url
@@ -120,7 +122,7 @@ class Company(Scraper):
         driver = self.driver
 
         try:
-            see_all_employees = driver.find_element_by_xpath('//a[@data-control-name="topcard_see_all_employees"]')
+            see_all_employees = driver.find_element(By.XPATH,'//a[@data-control-name="topcard_see_all_employees"]')
         except:
             pass
         driver.get(os.path.join(self.linkedin_url, "people"))
@@ -156,7 +158,7 @@ class Company(Scraper):
         results_li_len = len(results_li)
         while is_loaded(results_li_len):
             try:
-                driver.find_element_by_xpath(next_xpath).click()
+                driver.find_element(By.XPATH,next_xpath).click()
             except:
                 pass
             _ = WebDriverWait(driver, wait_time).until(EC.presence_of_element_located((By.CLASS_NAME, list_css)))
@@ -185,7 +187,7 @@ class Company(Scraper):
 
         navigation = driver.find_element_by_class_name("org-page-navigation__items ")
 
-        self.name = driver.find_element_by_xpath('//span[@dir="ltr"]').text.strip()
+        self.name = driver.find_element(By.XPATH,'//span[@dir="ltr"]').text.strip()
 
         # Click About Tab or View All Link
         try:
@@ -203,14 +205,19 @@ class Company(Scraper):
             section_id = 4
         else:
             section_id = 3
-        grid = driver.find_elements_by_tag_name("section")[section_id]
+       #section ID is no longer needed, we are using class name now.
+        #grid = driver.find_elements_by_tag_name("section")[section_id]
+        grid = driver.find_element_by_class_name("artdeco-card.p5.mb4")
+        print(grid)
         descWrapper = grid.find_elements_by_tag_name("p")
         if len(descWrapper) > 0:
             self.about_us = descWrapper[0].text.strip()
-
         labels = grid.find_elements_by_tag_name("dt")
         values = grid.find_elements_by_tag_name("dd")
         num_attributes = min(len(labels), len(values))
+        #print("The length of the labels is " + str(len(labels)), "The length of the values is " + str(len(values)))
+        # if num_attributes == 0:
+        #     exit()
         x_off = 0
         for i in range(num_attributes):
             txt = labels[i].text.strip()
@@ -231,13 +238,20 @@ class Company(Scraper):
             elif txt == 'Specialties':
                 self.specialties = "\n".join(values[i+x_off].text.strip().split(", "))
 
+        grid = driver.find_element_by_class_name("mt1")
+        spans = grid.find_elements_by_tag_name("span")
+        for span in spans:
+            txt = span.text.strip()
+            if "See all" in txt and "employees on LinkedIn" in txt:
+                self.headcount = int(txt.replace("See all", "").replace("employees on LinkedIn", "").strip())
+
         driver.execute_script("window.scrollTo(0, Math.ceil(document.body.scrollHeight/2));")
 
 
         try:
             _ = WebDriverWait(driver, 3).until(EC.presence_of_element_located((By.CLASS_NAME, 'company-list')))
             showcase, affiliated = driver.find_elements_by_class_name("company-list")
-            driver.find_element_by_id("org-related-companies-module__show-more-btn").click()
+            driver.find_element(By.ID,"org-related-companies-module__show-more-btn").click()
 
             # get showcase
             for showcase_company in showcase.find_elements_by_class_name("org-company-card"):
@@ -289,7 +303,7 @@ class Company(Scraper):
 
         # get showcase
         try:
-            driver.find_element_by_id("view-other-showcase-pages-dialog").click()
+            driver.find_element(By.ID,"view-other-showcase-pages-dialog").click()
             WebDriverWait(driver, 3).until(EC.presence_of_element_located((By.ID, 'dialog')))
 
             showcase_pages = driver.find_elements_by_class_name("company-showcase-pages")[1]
@@ -341,6 +355,7 @@ class Company(Scraper):
         _output['founded'] = self.founded
         _output['affiliated_companies'] = self.affiliated_companies
         _output['employees'] = self.employees
+        _output['headcount'] = self.headcount
         
         return json.dumps(_output).replace('\n', '')
 
