@@ -1,2 +1,2 @@
-VERIFY_LOGIN_ID = "global-nav-search"
+VERIFY_LOGIN_ID = "global-nav__primary-link"
 REMEMBER_PROMPT = 'remember-me-prompt__form-primary'
