@@ -60,7 +60,7 @@ class Scraper:
 
     def is_signed_in(self):
         try:
-            self.driver.find_element(By.ID,c.VERIFY_LOGIN_ID)
+            self.driver.find_element(By.CLASS_NAME, c.VERIFY_LOGIN_ID)
             return True
         except:
             pass
